@@ -2,12 +2,11 @@
 
 """This module implements the base CCDData class."""
 
-from astropy.nddata import fits_ccddata_reader, fits_ccddata_writer, CCDData
+from astropy.nddata import CCDData, fits_ccddata_reader, fits_ccddata_writer
 
-
-__all__ = ['CCDData', 'fits_ccddata_reader', 'fits_ccddata_writer']
+__all__ = ["CCDData", "fits_ccddata_reader", "fits_ccddata_writer"]
 
 
 # This should be be a tuple to ensure it isn't inadvertently changed
 # elsewhere.
-_recognized_fits_file_extensions = ('fit', 'fits', 'fts')
+_recognized_fits_file_extensions = ("fit", "fits", "fts")
