@@ -2,9 +2,7 @@
 
 import numpy as np
 import pytest
-
 from astropy.nddata import StdDevUncertainty
-
 from astropy.utils.exceptions import AstropyDeprecationWarning
 
 from ccdproc.core import rebin
@@ -55,9 +53,7 @@ def test_rebin_smaller():
 
 
 # test rebinning with ccddata object
-@pytest.mark.parametrize('mask_data, uncertainty', [
-                         (False, False),
-                         (True, True)])
+@pytest.mark.parametrize("mask_data, uncertainty", [(False, False), (True, True)])
 def test_rebin_ccddata(mask_data, uncertainty):
     ccd_data = ccd_data_func(data_size=10)
     if mask_data:
